@@ -88,6 +88,7 @@ class GraphQLPostman(BasePostman):
         persist=True,
         log=False,
         reference: str = None,
+        parent: Union[AssignationFragment, str] = None,
     ) -> asyncio.Queue:
         async with self._lock:
             if not self._watching:
@@ -99,7 +100,7 @@ class GraphQLPostman(BasePostman):
         self.assignations[reference] = None
         self._ass_update_queues[reference] = asyncio.Queue()
         assignation = await aassign(
-            reservation=reservation, args=args, reference=reference
+            reservation=reservation, args=args, reference=reference, parent=parent
         )
         await self._ass_update_queue.put(assignation)
         return self._ass_update_queues[reference]
@@ -141,6 +142,7 @@ class GraphQLPostman(BasePostman):
 
         async for assignation in awatch_requests("default"):
             ass = assignation.update or assignation.create
+            print("sreocinsoien", ass)
             await self._ass_update_queue.put(ass)
 
     async def watch_resraces(self):
