@@ -5,8 +5,8 @@ def SliderWidget(min=0, max=0):
     return WidgetInput(kind="SliderWidget", min=min, max=max)
 
 
-def SearchWidget(query=""):
-    return WidgetInput(kind="SearchWidget", query=query)
+def SearchWidget(query, ward):
+    return WidgetInput(kind="SearchWidget", query=query, ward=ward)
 
 
 def ImageReturnWidget(query=""):
